@@ -51,7 +51,7 @@ def to_yolo(pxl_annotations_dict=None,labelmap=None, base_imgdir=None, targetdir
         
 
         if copy_image:
-            img.save(os.path.join(targetdir,"images", step, img_id.split('.')[0] + '.png', ), 'PNG')
+            img.save(os.path.join(targetdir,"images", step, os.path.splitext(img_id)[0] + '.png', ), 'PNG')
         else:
             shutil.move(os.path.join(base_imgdir, img_id), os.path.join(targetdir, 'images', step, img_id))
 
@@ -98,15 +98,13 @@ def to_yolo(pxl_annotations_dict=None,labelmap=None, base_imgdir=None, targetdir
         
 def find_matching_annotations(dict_annotations=None, imgpath=None):
     for ann in dict_annotations["annotations"]:
-        print(imgpath)
-        print(imgpath.split('/')[-1])
         if imgpath.split('/')[-1] == ann["external_picture_url"]:
             return True, ann 
     return False, None
 
 
 def generate_yaml(yamlname, targetdir, labelmap):
-    print("updated")
+    print("Data yaml updated")
     if not os.path.isdir(os.path.join(targetdir, "data")):
         os.mkdir(os.path.join(targetdir, "data"))
 
@@ -200,7 +198,7 @@ def tf_events_to_dict(path, type=''):
     return log_dict
 
 
-def setup_hyp(exp_name, cfg, checkpoint_dir, config_dir, params={}, label_map=[]):
+def setup_hyp(exp_name, cfg, checkpoint_dir, params={}, label_map=[]):
     YOLOSIZE = cfg.split('/')[2][6]
     YOLODIR = 'YOLO-{}'.format(exp_name)
 
@@ -211,10 +209,9 @@ def setup_hyp(exp_name, cfg, checkpoint_dir, config_dir, params={}, label_map=[]
     for f in tmp:
         if f.endswith('.pt'):
             weight_path = os.path.join(checkpoint_dir, f)
-
-    for ff in os.listdir(config_dir):
-        if ff.endswith('{}.yaml'.format(exp_name)):
-            hyp_path = os.path.join(config_dir, ff)
+        if f.endswith('{}.yaml'.format(exp_name)):
+            hyp_path = os.path.join(checkpoint_dir, f)
+    
 
     opt = Opt()
     opt.batch_size = 4 if not 'batch_size' in params.keys() else params["batch_size"]
